@@ -14,18 +14,18 @@ import multiprocessing
 from typing import Union
 
 
-__version__ = "0.4.0"
+__version__ = "0.5.0"
 
 
 ALL      = - 0x80
-TRACE    = - 0x40   # - 0x50 -> - 0x31
-DEBUG    = - 0x20   # - 0x30 -> - 0x11
-INFO     =   0x00   # - 0x10 ->   0x0F   stdout
-WARN     =   0x20   #   0x10 ->   0x2F   stderr
+TRACE    = - 0x40
+DEBUG    = - 0x20
+INFO     =   0x00
+WARN     =   0x20
 WARNING  =   0x20
 SEVERE   =   0x30
-ERROR    =   0x40   #   0x30 ->   0x4F
-FATAL    =   0x60   #   0x50 ->   0x6F
+ERROR    =   0x40
+FATAL    =   0x60
 CRITICAL =   0x60
 OFF      =   0x7F
 
@@ -51,13 +51,10 @@ VARIABLE_TABLE = """ $(variable)
 
 
 class FORMAT(object):
-    # 朴素
     SIMPLE = '[$(.levelname)] $(.message)'
 
-    # 默认
     DEFAULT = '[$(.date) $(.time)] [$(.thread)/$(.levelname)] $(.message)'
 
-    # 调试
     DEBUG = '[$(.date) $(.time).$(.moment)] $(.file) [$(.thread)/$(.levelname)] [line:$(.line)] $(.message)'
 
 
@@ -73,15 +70,16 @@ levelTable = {
     'fatal': (FATAL, 'FATAL'),
     'critical': (CRITICAL, 'CRITICAL')
 }
+#? levelTable[alias] = [level, levelname]
 
 
 
 def op_character_variable(op_format: str, table: dict) -> str:
     if not isinstance(op_format, str):
-        raise TypeError('op_format is not of type str')
+        raise TypeError('The op_format type is not str.')
 
     if not isinstance(table, dict):
-        raise TypeError('table is not of type dict')
+        raise TypeError('The table type is not dict.')
 
     op = op_format
     for key, value in table.items():
@@ -114,13 +112,13 @@ class BaseLogop(object):
 class Logop_standard(BaseLogop):
     def call(self, content: dict, op_format: str = FORMAT.DEFAULT) -> None:
         if not isinstance(content, dict):
-            raise TypeError('content is not of type dict')
+            raise TypeError('The content type is not dict.')
 
         if not isinstance(op_format, str):
-            raise TypeError('op_format is not of type str')
+            raise TypeError('The type op_format is not str.')
 
         if '$(.message)' not in op_format:
-            raise ValueError('$(.message) must be included in format')
+            raise ValueError('$(.message) must be included in format.')
 
         op = op_character_variable(op_format, content)
         ops = f'{op}\n'
@@ -139,13 +137,13 @@ class Logop_standard(BaseLogop):
 class Logop_standard_up(BaseLogop):
     def call(self, content: dict, op_format: str = FORMAT.DEFAULT) -> None:
         if not isinstance(content, dict):
-            raise TypeError('content is not of type dict')
+            raise TypeError('The content type is not dict.')
 
         if not isinstance(op_format, str):
-            raise TypeError('op_format is not of type str')
+            raise TypeError('The op_format type is not str.')
 
         if '$(.message)' not in op_format:
-            raise ValueError('$(.message) must be included in format')
+            raise ValueError('$(.message) must be included in format.')
 
         op = op_character_variable(op_format, content)
         level = content.get('level', 0)
@@ -182,10 +180,10 @@ class Logop_file(BaseLogop):
             self.op_name = name
 
         if not isinstance(pathdir, (str, list, tuple)):
-            raise TypeError('The pathdir type is not str, list or tuple')
+            raise TypeError('The pathdir type is not str, list or tuple.')
 
         if not isinstance(pathname, str):
-            raise TypeError('The pathname type is not str')
+            raise TypeError('The pathname type is not str.')
 
         if isinstance(pathdir, str):
             self._pathdir = pathdir
@@ -194,7 +192,7 @@ class Logop_file(BaseLogop):
             self._pathdir = os.path.join(pathdir)
 
         else:
-            raise Exception('Errors that should not occur')
+            raise Exception('Errors that should not occur.')
 
         self._pathname = pathname
         self._encoding = encoding
@@ -218,13 +216,12 @@ class Logop_file(BaseLogop):
 
 
 class Logging(object):
-    __level = INFO
-    __op_format = FORMAT.DEFAULT
-    __op_list = []
-
-
     def __init__(self, level: int = INFO, op_format: str = FORMAT.DEFAULT,
                  *, stdout: bool = True, asynchronous: bool = False, threadname: str = 'LoggingThread'):
+        self.__level = INFO
+        self.__op_format = FORMAT.DEFAULT
+        self.__op_list = []
+
         self.__call_lock = threading.RLock()
         self.__set_lock = threading.RLock()
 
@@ -242,24 +239,33 @@ class Logging(object):
             self.__asynchronous_task.start()
 
 
-    def setlevel(self, level: int) -> None:
+    def setlevel(self, level:   Union[int, str]) -> None:
         with self.__set_lock:
-            if not isinstance(level, int):
-                raise TypeError('level is not of type int')
+            if isinstance(level, int):
+                lv = level
+
+            elif isinstance(level, str):
+                if level not in levelTable:
+                    raise ValueError('The level alias does not exist.')
+                
+                lv = levelTable[level][0]
+
+            else:
+                raise TypeError('The level type is not int.')
 
             if not -0x80 <= level <= 0x7F:
-                raise ValueError('level should be somewhere between -0x80 to 0x7F ')
+                raise ValueError('level should be somewhere between -0x80 to 0x7F .')
 
-            self.__level = level
+            self.__level = lv
 
 
     def setformat(self, op_format: str) -> None:
         with self.__set_lock:
             if not isinstance(op_format, str):
-                raise TypeError('op_format is not of type str')
+                raise TypeError('The op_format type is not str.')
 
             if '$(.message)' not in op_format:
-                raise ValueError('$(.message) must be included in format')
+                raise ValueError('$(.message) must be included in format.')
 
             self.__op_format = op_format
 
@@ -267,16 +273,16 @@ class Logging(object):
     def add_op(self, target: BaseLogop) -> None:
         with self.__set_lock:
             if not isinstance(target, BaseLogop):
-                raise TypeError('The target type is not op_object')
+                raise TypeError('The target type is not op_object.')
 
             if len(self.__op_list) > 0x10:
-                raise Warning('There are too many op objects')
+                raise Warning('There are too many op objects.')
 
             standard = BaseLogop.op_type
             typelist = [x.op_type for x in self.__op_list]
 
             if standard in typelist and target.op_type == standard:
-                raise ValueError('Only one standard op_object can exist')
+                raise ValueError('Only one standard op_object can exist.')
 
             identlist = [x.op_ident for x in self.__op_list]
             if identlist:
@@ -295,7 +301,7 @@ class Logging(object):
                 if op.op_ident == ident:
                     break
             else:
-                raise ValueError('The ident value does not exist')
+                raise ValueError('The ident value does not exist.')
 
             del self.__op_list[index]
 
@@ -468,4 +474,4 @@ class Logging(object):
 
     def __getattr__(self, __name):
         if __name in levelTable: return self.__get_call(__name)
-        else: raise AttributeError('This alias is not defined in the level table')
+        else: raise AttributeError('This alias is not defined in the level table.')
